|travis| |coverage| |version| |license| |pyversions| |implementation| |status| |format|

********************
travis-docker-python
********************

This repo consists of travis.yml to build dockerfile for python project.

.. |travis| image:: https://travis-ci.com/Shashankreddysunkara/travis-docker-python.svg?branch=main
    :target: https://travis-ci.com/Shashankreddysunkara/travis-docker-python
.. |coverage| image:: https://coveralls.io/repos/github/Shashankreddysunkara/travis-docker-python/badge.svg
    :target: https://coveralls.io/github/Shashankreddysunkara/travis-docker-python
.. |version| image:: https://img.shields.io/pypi/v/travis-docker-python.svg?style=flat-square
    :target: https://pypi.python.org/pypi/travis-docker-python
.. |implementation| image:: https://img.shields.io/pypi/implementation/travis-docker-python.svg?style=flat-square
    :target: https://pypi.python.org/pypi/travis-docker-python
.. |status| image:: https://img.shields.io/pypi/status/travis-docker-python.svg?style=flat-square
    :target: https://pypi.python.org/pypi/travis-docker-python
.. |pyversions| image:: https://img.shields.io/pypi/pyversions/travis-docker-python.svg?style=flat-square
    :target: https://pypi.python.org/pypi/travis-docker-python
.. |format| image:: https://img.shields.io/pypi/format/travis-docker-python.svg?style=flat-square
    :target: https://pypi.python.org/pypi/travis-docker-python
.. |license|  image:: https://img.shields.io/pypi/l/travis-docker-python.svg?style=flat-square
    :target: https://pypi.python.org/pypi/travis-docker-python

